Contributor's Guide
===================

Contributions are always welcome and greatly appreciated!

Code contributions
------------------


Documentation improvements
--------------------------


Bug reports
-----------


Feature requests and feedback
-----------------------------
